alphaChannelCount property
int
get
alphaChannelCount
Returns the number of alpha channels in the document.
Implementation
int get alphaChannelCount => alphaChannels.length;
Returns the number of alpha channels in the document.
int get alphaChannelCount => alphaChannels.length;