attributeCount property
int
get
attributeCount
Returns the number of metadata attributes in the document.
Implementation
int get attributeCount => attributes?.length ?? 0;
Returns the number of metadata attributes in the document.
int get attributeCount => attributes?.length ?? 0;